＃ 安全

## 組み込みプリミティブ

- JWT ガード
- APIキーマネージャー
- CORS プロファイル
- CSRFプロテクター
- 秘密マネージャー
- 監査ロガー

## ベストプラクティス

- シークレットとキーをローテーションする
- 運用環境では厳密な CORS を使用する
- 機密ルートの認証チェックを強制する
- 相関 ID を使用してセキュリティ イベントをログに記録します